@@ -4,7 +4,7 @@
  * Authors		: Patrick Lecoanet.
  * Creation date	: Wed Jun 23 10:09:20 1999
  *
- * $Id: Group.c,v 1.49 2004/09/09 07:58:08 lecoanet Exp $
+ * $Id: Group.c,v 1.39 2003/10/02 07:48:23 lecoanet Exp $
  */
 
 /*
@@ -39,7 +39,7 @@
 #endif
 
 
-static const char rcsid[] = "$Id: Group.c,v 1.49 2004/09/09 07:58:08 lecoanet Exp $";
+static const char rcsid[] = "$Id: Group.c,v 1.39 2003/10/02 07:48:23 lecoanet Exp $";
 static const char compile_id[]="$Compile: " __FILE__ " " __DATE__ " " __TIME__ " $";
 
 
@@ -52,7 +52,7 @@ typedef struct _GroupItemStruct {
   /* Public data */
   ZnItem		clip;
   unsigned char		alpha;
-
+  
   /* Private data */
   ZnItem		head;		/* Doubly linked list of all items.	*/
   ZnItem		tail;
@@ -471,7 +471,7 @@ Query(ZnItem		item,
       int		argc __unused,
       Tcl_Obj *CONST	argv[])
 {
-  if (ZnQueryAttribute(item->wi->interp, item, group_attrs, argv[0]) == TCL_ERROR) {
+  if (ZnQueryAttribute(item->wi, item, group_attrs, argv[0]) == TCL_ERROR) {
     return TCL_ERROR;
   }
 
@@ -551,23 +551,13 @@ PopClip(GroupItem	group,
 static void
 PushTransform(ZnItem	item)
 {
-  ZnPoint *pos;
-  
-  pos = NULL;
-  if (item->class->pos_offset >= 0) {
-    pos = (ZnPoint *) (((char *) item) + item->class->pos_offset);
-    if (pos->x == 0 && pos->y == 0) {
-      pos = NULL;
-    }
-  }
   if (!item->transfo &&
-      !pos &&
       ISSET(item->flags, ZN_COMPOSE_SCALE_BIT) &&
       ISSET(item->flags, ZN_COMPOSE_ROTATION_BIT)) {
     return;
   }
 
-  ZnPushTransform(item->wi, item->transfo, pos,
+  ZnPushTransform(item->wi, item->transfo,
 		  ISSET(item->flags, ZN_COMPOSE_SCALE_BIT),
 		  ISSET(item->flags, ZN_COMPOSE_ROTATION_BIT));
   /*printf("Pushing transfo for item: %d\n;", item->id);
@@ -586,17 +576,7 @@ PushTransform(ZnItem	item)
 static void
 PopTransform(ZnItem	item)
 {
-  ZnPoint *pos;
-  
-  pos = NULL;
-  if (item->class->pos_offset >= 0) {
-    pos = (ZnPoint *) (((char *) item) + item->class->pos_offset);
-    if (pos->x == 0 && pos->y == 0) {
-      pos = NULL;
-    }
-  }
   if (!item->transfo &&
-      !pos &&
       ISSET(item->flags, ZN_COMPOSE_SCALE_BIT) &&
       ISSET(item->flags, ZN_COMPOSE_ROTATION_BIT)) {
     return;
@@ -701,7 +681,6 @@ ComputeCoordinates(ZnItem	item,
   ZnItem	current_item;
   ZnItem	*deps;
   int		num_deps, i;
-  ZnBBox	*clip_box;
 
   PushTransform(item);
   /*  printf("Group.c\n");
@@ -804,14 +783,6 @@ ComputeCoordinates(ZnItem	item,
     ZnAddBBoxToBBox(&item->item_bounding_box, &current_item->item_bounding_box);
     current_item = current_item->next;    
   }
-  /*
-   * Limit the group actual bounding box to
-   * the clip shape boundary.
-   */
-  if (group->clip) {
-    clip_box = &group->clip->item_bounding_box;
-    ZnIntersectBBox(&item->item_bounding_box, clip_box, &item->item_bounding_box);
-  }
   item->inv_flags = 0;
 
   PopClip(group, False);
@@ -884,7 +855,7 @@ ToArea(ZnItem	item,
      * ask the child groups to report instead of adding their
      * children to the result.
      */
-    atomic = ISSET(item->flags, ATOMIC_BIT) && !ta->override_atomic;
+    atomic = ISSET(item->flags, ATOMIC_BIT);
     ta->report |= atomic;
   }
 
@@ -911,7 +882,7 @@ ToArea(ZnItem	item,
       continue;
     }
     /*printf("bbox test passed %d\n", current_item?current_item->id:0);*/
-    if ((current_item->class != ZnGroup) || atomic || ta->recursive || ISSET(current_item->flags, ATOMIC_BIT)) {
+    if ((current_item->class != ZnGroup) || atomic || ta->recursive) {
       if (current_item->class != ZnGroup) {
 	/*printf("testing %d\n", current_item?current_item->id:0);*/
 	PushTransform(current_item);
@@ -1077,7 +1048,7 @@ Render(ZnItem 	item)
   PushTransform(item);
   PushClip(group, True);
 #ifdef GL_DAMAGE
-  if (ISCLEAR(wi->flags, ZN_CONFIGURE_EVENT) && (group->clip != ZN_NO_ITEM)) {
+  if (group->clip != ZN_NO_ITEM) {
     old_damaged_area = wi->damaged_area;
     if (ZnCurrentClip(wi, NULL, &clip_box, NULL)) {
       ZnIntersectBBox(&wi->damaged_area, clip_box, &bbox);
@@ -1091,7 +1062,7 @@ Render(ZnItem 	item)
     if (ISSET(current_item->flags, ZN_VISIBLE_BIT)) {
 #ifdef GL_DAMAGE
       ZnIntersectBBox(&wi->damaged_area, &current_item->item_bounding_box, &bbox);
-      if (!ZnIsEmptyBBox(&bbox) || ISSET(wi->flags, ZN_CONFIGURE_EVENT)) {
+      if (!ZnIsEmptyBBox(&bbox)) {
 #endif
 	if (current_item->class != ZnGroup) {
 	  PushTransform(current_item);
@@ -1112,7 +1083,7 @@ Render(ZnItem 	item)
   }
 
 #ifdef GL_DAMAGE
-  if (ISCLEAR(wi->flags, ZN_CONFIGURE_EVENT) && (group->clip != ZN_NO_ITEM)) {
+  if (group->clip != ZN_NO_ITEM) {
     wi->damaged_area = old_damaged_area;
   }
 #endif
@@ -1185,7 +1156,6 @@ Pick(ZnItem	item,
   ZnBBox	bbox, inter, *clip_box;
   ZnPoint	*p = ps->point;
   ZnBool	atomic;
-  TkRegion	reg;
 
   ps->a_item= ZN_NO_ITEM;
   ps->a_part = ZN_NO_PART;
@@ -1233,18 +1203,15 @@ Pick(ZnItem	item,
   bbox.corner.x = p->x + (aperture?aperture:1);
   bbox.corner.y = p->y + (aperture?aperture:1);
 
-  if (ZnCurrentClip(wi, &reg, &clip_box, NULL)) {
+  if (ZnCurrentClip(wi, NULL, &clip_box, NULL)) {
     ZnIntersectBBox(&bbox, clip_box, &inter);
     if (ZnIsEmptyBBox(&inter)) {
       goto out;
     }
-    if (reg && !ZnPointInRegion(reg, p->x, p->y)) {
-      goto out;
-    }
   }
-
+  
   current_item = (ps->start_item == ZN_NO_ITEM) ? group->head : ps->start_item;
-  atomic = ISSET(item->flags, ATOMIC_BIT) && !ps->override_atomic;
+  atomic = ISSET(item->flags, ATOMIC_BIT);
 
   for ( ; current_item != ZN_NO_ITEM; current_item = current_item->next) {
     /*
@@ -1256,10 +1223,6 @@ Pick(ZnItem	item,
 	ISCLEAR(current_item->flags, ZN_VISIBLE_BIT)) {
       continue;
     }
-    ZnIntersectBBox(&bbox, &current_item->item_bounding_box, &inter);
-    if (ZnIsEmptyBBox(&inter)) {
-      continue;
-    }
     if (current_item->class != ZnGroup) {
       PushTransform(current_item);
       p_item = ps->a_item;
@@ -1328,7 +1291,7 @@ Coords(ZnItem		item,
 {
   if ((cmd == ZN_COORDS_ADD) || (cmd == ZN_COORDS_ADD_LAST) || (cmd == ZN_COORDS_REMOVE)) {
     Tcl_AppendResult(item->wi->interp,
-		     " can't add or remove vertices in groups", NULL);
+		     " groups can't add or remove vertices", NULL);
     return TCL_ERROR;
   }
   else if ((cmd == ZN_COORDS_REPLACE) || (cmd == ZN_COORDS_REPLACE_ALL)) {
@@ -1337,20 +1300,17 @@ Coords(ZnItem		item,
 		       " coords command need 1 point on groups", NULL);
       return TCL_ERROR;
     }
-    if (!item->transfo && ((*pts)[0].x == 0.0) && ((*pts)[0].y == 0.0)) {
-      return TCL_OK;
-    }
     if (!item->transfo) {
       item->transfo = ZnTransfoNew();
     }
-    ZnTranslate(item->transfo, (*pts)[0].x, (*pts)[0].y, True);
+    ZnSetTranslation(item->transfo, (*pts)[0].x, (*pts)[0].y);
     ZnITEM.Invalidate(item, ZN_TRANSFO_FLAG);
   }
   else if ((cmd == ZN_COORDS_READ) || (cmd == ZN_COORDS_READ_ALL)) {
     ZnPoint	*p;
     
-    ZnListAssertSize(ZnWorkPoints, 1);
-    p = (ZnPoint *) ZnListArray(ZnWorkPoints);
+    ZnListAssertSize(item->wi->work_pts, 1);
+    p = (ZnPoint *) ZnListArray(item->wi->work_pts);
     ZnTransfoDecompose(item->transfo, NULL, p, NULL, NULL);
     *num_pts = 1;
     *pts = p;
@@ -1367,8 +1327,8 @@ Coords(ZnItem		item,
  **********************************************************************************
  */
 static void
-PostScript(ZnItem	item __unused,
-	   ZnBool	prepass __unused)
+PostScript(ZnItem		item __unused,
+	   ZnPostScriptInfo	ps_info __unused)
 {
 }
 
@@ -1696,12 +1656,11 @@ GetAnchor(ZnItem	item,
  **********************************************************************************
  */
 static ZnItemClassStruct GROUP_ITEM_CLASS = {
-  "group",
   sizeof(GroupItemStruct),
-  group_attrs,
   0,			/* num_parts */
-  ZN_CLASS_ONE_COORD,	/* flags */
-  -1,
+  False,		/* has_anchors */
+  "group",
+  group_attrs,
   Init,
   Clone,
   Destroy,
