@@ -4,7 +4,7 @@
  * Authors		: Patrick Lecoanet.
  * Creation date	: 
  *
- * $Id: Transfo.c,v 1.14 2004/04/30 14:33:17 lecoanet Exp $
+ * $Id: Transfo.c,v 1.11 2003/12/11 08:20:16 lecoanet Exp $
  */
 
 /*
@@ -151,16 +151,10 @@ ZnPrintTransfo(ZnTransfo	*t)
    * 0  sy	-sin(rot) cos(rot)	tan(skewx) 1	        0  1
    * 0  0	0         0		0          0	        tx ty
    */
-  if (t) {
-    printf("(%5g %5g\n %5g %5g\n %5g %5g)\n",
-	   t->_[0][0], t->_[0][1],
-	   t->_[1][0], t->_[1][1],
-	   t->_[2][0], t->_[2][1]);
-  }
-  else {
-    printf("(%5g %5g\n %5g %5g\n %5g %5g)\n",
-	   1.0, 0.0, 0.0, 1.0, 0.0, 0.0);
-  }
+  printf("(%5g %5g\n %5g %5g\n %5g %5g)\n",
+	 t->_[0][0], t->_[0][1],
+	 t->_[1][0], t->_[1][1],
+	 t->_[2][0], t->_[2][1]);
 }
 
 
@@ -233,7 +227,7 @@ ZnTransfoCompose(ZnTransfo	*res,
 		 ZnTransfo	*t2)
 {
   if ((t1 != NULL) && (t2 != NULL)) {
-    register float	tmp;
+    register ZnReal	tmp;
 
     tmp = t1->_[0][0];
     res->_[0][0] = tmp*t2->_[0][0] + t1->_[0][1]*t2->_[1][0];
@@ -280,11 +274,10 @@ ZnTransfo *
 ZnTransfoInvert(ZnTransfo	*t,
 		ZnTransfo	*inv)
 {
-  float	pos, neg, temp, det_l;
+  ZnReal	pos, neg, temp, det_l;
 
   if (t == NULL) {
-    ZnTransfoSetIdentity(inv);
-    return inv;
+    return NULL;
   }
 
   /*
@@ -314,7 +307,7 @@ ZnTransfoInvert(ZnTransfo	*t,
     return NULL;
   }
   
-  det_l = 1 / det_l;
+  det_l = 1.0/ det_l;
   inv->_[0][0] = t->_[1][1] * det_l;
   inv->_[0][1] = - t->_[0][1] * det_l;
   inv->_[1][0] = - t->_[1][0] * det_l;
@@ -354,7 +347,7 @@ ZnTransfoDecompose(ZnTransfo	*t,
 		   ZnReal	*skewxy)
 {
   ZnTransfo	local;
-  float		skew, len, rot, det;
+  ZnReal	skew, len, rot, det;
   
   if (t == NULL) {
     /* Identity transform */
@@ -394,8 +387,8 @@ ZnTransfoDecompose(ZnTransfo	*t,
   }
 
   /* Get scale and skew */
-  len = (float) sqrt(local._[0][0]*local._[0][0] +
-		     local._[0][1]*local._[0][1]); /* Get x scale from 1st row */
+  len = sqrt(local._[0][0]*local._[0][0] +
+	     local._[0][1]*local._[0][1]); /* Get x scale from 1st row */
   if (scale) {
     scale->x = len < PRECISION_LIMIT ? 0.0 : len;
   }
@@ -410,8 +403,8 @@ ZnTransfoDecompose(ZnTransfo	*t,
    */
   local._[1][0] -= local._[0][0]*skew;
   local._[1][1] -= local._[0][1]*skew;
-  len = (float) sqrt(local._[1][0]*local._[1][0] +
-		     local._[1][1]*local._[1][1]); /* Get y scale from 2nd row */
+  len = sqrt(local._[1][0]*local._[1][0] +
+	     local._[1][1]*local._[1][1]); /* Get y scale from 2nd row */
   if (scale) {
     scale->y = len < PRECISION_LIMIT ? 0.0 : len;
   }
@@ -444,11 +437,11 @@ ZnTransfoDecompose(ZnTransfo	*t,
    */
   det = (local._[0][0]*local._[1][1]- local._[0][1]*local._[1][0]);
   
-  rot = (float) atan2(local._[0][1], local._[0][0]);
+  rot = atan2(local._[0][1], local._[0][0]);
   if (rot < 0) {
-    rot = (2 * (float) M_PI) + rot;
+    rot = 2*M_PI+rot;
   }
-  rot = rot < PRECISION_LIMIT ? 0 : rot;
+  rot = rot < PRECISION_LIMIT ? 0.0 : rot;
   if (rot >= M_PI) {
     /*rot -= M_PI;  Why that, I'll have to check Graphic Gems ??? */
     if (scale && det < 0) {
@@ -528,13 +521,10 @@ ZnTransfoHasSkew(ZnTransfo	*t)
 ZnBool
 ZnTransfoIsTranslation(ZnTransfo	*t)
 {
-  if (!t) {
-    return True;
-  }
-  return (t->_[0][0] == 1.0 &&
+  return (t->_[0][0] == 0.0 &&
 	  t->_[0][1] == 0.0 &&
 	  t->_[1][0] == 0.0 &&
-	  t->_[1][1] == 1.0);
+	  t->_[1][1] == 0.0);
 }
 
 
@@ -544,7 +534,6 @@ ZnTransfoIsTranslation(ZnTransfo	*t)
  * ZnTransformPoint --
  *	Apply the transformation to the point. The point is
  *	modified and returned as the value of the function.
- *	It is safe for p and xp to be the same point (structure).
  *	A NULL transformation means identity. This is only used
  *	in the toolkit to optimize some cases. It should never
  *	happen in user code.
@@ -561,10 +550,8 @@ ZnTransformPoint(ZnTransfo		*t,
     xp->y = p->y;
   }
   else {
-    ZnReal a;
-    a = t->_[0][0]*p->x + t->_[1][0]*p->y + t->_[2][0];
+    xp->x = t->_[0][0]*p->x + t->_[1][0]*p->y + t->_[2][0];
     xp->y = t->_[0][1]*p->x + t->_[1][1]*p->y + t->_[2][1];
-    xp->x = a;
   }
   return xp;
 }
@@ -575,7 +562,6 @@ ZnTransformPoint(ZnTransfo		*t,
  *
  * ZnTransformPoints --
  *	Apply the transformation to the points in p returning points in xp.
- *	It is safe for p and xp to be the same array of ponits.
  *	The number of points is in num.
  *	A NULL transformation means identity. This is only used
  *	in the toolkit to optimize some cases. It should never
@@ -596,10 +582,8 @@ ZnTransformPoints(ZnTransfo	*t,
     unsigned int i;
 
     for (i = 0; i < num; i++) {
-      ZnReal a;
-      a = t->_[0][0]*p[i].x + t->_[1][0]*p[i].y + t->_[2][0];
+      xp[i].x = t->_[0][0]*p[i].x + t->_[1][0]*p[i].y + t->_[2][0];
       xp[i].y = t->_[0][1]*p[i].x + t->_[1][1]*p[i].y + t->_[2][1];
-      xp[i].x = a;
     }
   }
 }
@@ -610,29 +594,37 @@ ZnTransformPoints(ZnTransfo	*t,
  *
  * ZnTranslate --
  *	Translate the given transformation by delta_x, delta_y. Returns
- *	the resulting transformation. If abs is true, delta_x and
- *	delta_y are used to set the translation instead of adding deltas.
+ *	the resulting transformation.
+ *
+ * ZnSetTranslation --
+ *	Set the translation instead of combining it into the
+ *	transformation.
  *
  *************************************************************************
  */
 ZnTransfo *
 ZnTranslate(ZnTransfo	*t,
 	    ZnReal	delta_x,
-	    ZnReal	delta_y,
-	    ZnBool	abs)
+	    ZnReal	delta_y)
 {
-  if (abs) {
-    t->_[2][0] = (float) delta_x;
-    t->_[2][1] = (float) delta_y;
-  }
-  else {
-    t->_[2][0] = t->_[2][0] + (float) delta_x;
-    t->_[2][1] = t->_[2][1] + (float) delta_y;
-  }
+  t->_[2][0] = t->_[2][0] + delta_x;
+  t->_[2][1] = t->_[2][1] + delta_y;
 
   return t;
 }
 
+ZnTransfo *
+ZnSetTranslation(ZnTransfo	*t,
+		 ZnReal		delta_x,
+		 ZnReal		delta_y)
+{
+  t->_[2][0] = delta_x;
+  t->_[2][1] = delta_y;
+
+  return t;
+}
+
+
 /*
  *************************************************************************
  *
@@ -644,15 +636,15 @@ ZnTranslate(ZnTransfo	*t,
  */
 ZnTransfo *
 ZnScale(ZnTransfo	*t,
-	ZnReal		scale_x,
-	ZnReal		scale_y)
+	register ZnReal	scale_x,
+	register ZnReal	scale_y)
 {
-  t->_[0][0] = t->_[0][0] * (float) scale_x;
-  t->_[0][1] = t->_[0][1] * (float) scale_y;
-  t->_[1][0] = t->_[1][0] * (float) scale_x;
-  t->_[1][1] = t->_[1][1] * (float) scale_y;
-  t->_[2][0] = t->_[2][0] * (float) scale_x;
-  t->_[2][1] = t->_[2][1] * (float) scale_y;
+  t->_[0][0] = t->_[0][0]*scale_x;
+  t->_[0][1] = t->_[0][1]*scale_y;
+  t->_[1][0] = t->_[1][0]*scale_x;
+  t->_[1][1] = t->_[1][1]*scale_y;
+  t->_[2][0] = t->_[2][0]*scale_x;
+  t->_[2][1] = t->_[2][1]*scale_y;
   
   return t;
 }
@@ -672,10 +664,10 @@ ZnTransfo *
 ZnRotateRad(ZnTransfo	*t,
 	    ZnReal	angle)
 {
-  float	c = (float) cos(angle);
-  float	s = (float) sin(angle);
-  float	tmp;
-  
+  register ZnReal	c = cos(angle);
+  register ZnReal	s = sin(angle);
+  register ZnReal	tmp;
+
   tmp = t->_[0][0];
   t->_[0][0] = tmp*c - t->_[0][1]*s;
   t->_[0][1] = tmp*s + t->_[0][1]*c;
@@ -723,9 +715,9 @@ ZnSkewRad(ZnTransfo	*t,
 	  ZnReal	skew_x,
 	  ZnReal	skew_y)
 {
-  float	sx = (float) tan(skew_x);
-  float	sy = (float) tan(skew_y);
-  float	tmp;
+  register ZnReal	sx = tan(skew_x);
+  register ZnReal	sy = tan(skew_y);
+  register ZnReal	tmp;
 
   tmp = t->_[0][0];
   t->_[0][0] = tmp + t->_[0][1]*sx;
