@@ -29,10 +29,9 @@
 #include "Geo.h"
 #include "Types.h"
 #include "WidgetInfo.h"
-#include "tkZinc.h"
 
 
-static const char rcsid[] = "$Id: Window.c,v 1.14 2004/04/30 12:03:32 lecoanet Exp $";
+static const char rcsid[] = "$Id: Window.c,v 1.11 2003/10/02 09:09:11 lecoanet Exp $";
 static const char compile_id[] = "$Compile: " __FILE__ " " __DATE__ " " __TIME__ " $";
 
 /*
@@ -279,7 +278,7 @@ Configure(ZnItem	item,
      * to the old one.
      */
     if ((item->connected_item == ZN_NO_ITEM) ||
-	(ISSET(item->connected_item->class->flags, ZN_CLASS_HAS_ANCHORS) &&
+	(item->connected_item->class->has_anchors &&
 	 (item->parent == item->connected_item->parent))) {
       ZnITEM.UpdateItemDependency(item, old_connected);
     }
@@ -325,7 +324,7 @@ Query(ZnItem		item,
       int		argc __unused,
       Tcl_Obj *CONST	argv[])
 {
-  if (ZnQueryAttribute(item->wi->interp, item, wind_attrs, argv[0]) == TCL_ERROR) {
+  if (ZnQueryAttribute(item->wi, item, wind_attrs, argv[0]) == TCL_ERROR) {
     return TCL_ERROR;
   }  
 
@@ -378,9 +377,7 @@ ComputeCoordinates(ZnItem	item,
 					   &wind->pos_dev);
   }
   else {
-    ZnPoint pos;
-    pos.x = pos.y = 0.0;
-    ZnTransformPoint(wi->current_transfo, &pos, &wind->pos_dev);
+    ZnTransformPoint(wi->current_transfo, &wind->pos, &wind->pos_dev);
   }
   
   ZnAnchor2Origin(&wind->pos_dev, (ZnReal) wind->real_width, (ZnReal) wind->real_height,
@@ -545,8 +542,8 @@ Pick(ZnItem	item,
  **********************************************************************************
  */
 static void
-PostScript(ZnItem	item __unused,
-	   ZnBool	prepass __unused)
+PostScript(ZnItem		item __unused,
+	   ZnPostScriptInfo	ps_info __unused)
 {
 }
 
@@ -591,12 +588,12 @@ GetClipVertices(ZnItem		item,
   int		w=0, h=0;
   ZnPoint	*points;
   
-  ZnListAssertSize(ZnWorkPoints, 2);
+  ZnListAssertSize(item->wi->work_pts, 2);
   if (wind->win != NULL) {
     w = wind->real_width;
     h = wind->real_height;    
   }
-  points = ZnListArray(ZnWorkPoints);
+  points = ZnListArray(item->wi->work_pts);
   ZnTriStrip1(tristrip, points, 2, False);
   points[0] = wind->pos_dev;
   points[1].x = points[0].x + w;
@@ -657,12 +654,11 @@ Coords(ZnItem		item,
  **********************************************************************************
  */
 static ZnItemClassStruct WINDOW_ITEM_CLASS = {
-  "window",
   sizeof(WindowItemStruct),
-  wind_attrs,
   0,			/* num_parts */
-  ZN_CLASS_HAS_ANCHORS|ZN_CLASS_ONE_COORD, /* flags */
-  Tk_Offset(WindowItemStruct, pos),
+  True,			/* has_anchors */
+  "window",
+  wind_attrs,
   Init,
   Clone,
   Destroy,
